"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.buildLogicalExpression = buildLogicalExpression;
exports.buildMemberExpression = buildMemberExpression;

var _utils = require("./utils");

/**
 * Recursively build the needed logical expressions
 * @param {*} t - babel types (needed for building the ast)
 * @param {*} arr - the array the user needs to access
 * @param {array} tokens - the tokens from the access path
 */
function buildLogicalExpression(t, arr, tokens) {
  // base case
  if (tokens.length === 1) {
    return t.LogicalExpression("&&", t.identifier(arr),
    // use the last token for the final expression
    t.memberExpression(t.identifier(arr), t.identifier((0, _utils.sanitize)(tokens[0])),
    // check if the value is 'computed' (array access)
    (0, _utils.hasBrackets)(tokens[0])));
  }

  return t.LogicalExpression("&&",
  // continue building!
  buildLogicalExpression(t, arr, tokens.slice(0, -1)),
  // need to pass all of the tokens since the MemberExpression builder will take care of recursively removing tokens
  buildMemberExpression(t, arr, tokens));
}

/**
 * Recursively build the needed member expressions
 * @param {*} t - babel types (needed for building the ast)
 * @param {*} arr - the array the user needs to access
 * @param {array} tokens - the tokens from the access path
 */
function buildMemberExpression(t, arr, tokens) {
  // base case
  if (tokens.length === 1) {
    return t.memberExpression(t.identifier(arr), t.identifier((0, _utils.sanitize)(tokens[0])),
    // check if the value is 'computed' (array access)
    (0, _utils.hasBrackets)(tokens[0]));
  }

  return t.memberExpression(
  // continue building!
  buildMemberExpression(t, arr, tokens.slice(0, -1)),
  // need to remove brackets (if they exist) on the last item in the array
  t.identifier((0, _utils.sanitize)(tokens[tokens.length - 1])),
  // check if the value is 'computed' (array access)
  (0, _utils.hasBrackets)(tokens[tokens.length - 1]));
}